﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;

namespace BT
{
    public partial class Form1 : Form
    {
        enum comandi
        {
            Stop = 'S',
            Avanti = 'F',
            AvantiLento = 'f',
            Indietro = 'B',
            IndietroLento = 'b',
            Sinistra = 'L',
            SinistraLento = 'l',
            Destra = 'R',
            DestraLento = 'r',
            CameraSu = 'U',
            CameraGiu = 'D'
        }

        int conta = 0;
        comandi ultimoComando = comandi.Stop;
        bool connesso = false;

        SerialPort _serialPort;
   

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.KeyPreview = true;
            this.KeyUp += new KeyEventHandler(Form1_KeyUp);
            this.KeyDown += new KeyEventHandler(Form1_KeyDown);
        }
       
        void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Up:
                    if (e.Alt)
                        inviaComando(comandi.CameraSu);
                    else
                        if(e.Control)
                            inviaComando(comandi.AvantiLento);
                        else
                            inviaComando(comandi.Avanti);
                    break;

                case Keys.Down:
                    if (e.Alt)
                        inviaComando(comandi.CameraGiu);
                    else
                        if(e.Control)
                            inviaComando(comandi.IndietroLento);
                        else
                            inviaComando(comandi.Indietro);
                    break;

                case Keys.Left:
                    if(e.Control)
                        inviaComando(comandi.SinistraLento);
                    else
                        inviaComando(comandi.Sinistra);
                    break;

                case Keys.Right:
                    if(e.Control)
                        inviaComando(comandi.DestraLento);
                    else
                        inviaComando(comandi.Destra);
                    break;

                default:
                    inviaComando(comandi.Stop);
                    break;
            }
            
        }

        void inviaComando(comandi comando)
        {
            if (connesso)
            {
                // Domanda: meglio inviare continuamente i comandi o solo quando questo cambia?
                // Nel primo caso la perdita di connessione viene sentita come un "non comando" e quindi avviene lo stop
                // Nel secondo si limita l'uso della connessione ma si deve implementare un sistema per controllare se la connessione
                // è presente e nel caso fermare il robot
               // if (ultimoComando != comando)  
                {
                    conta++;
                    ultimoComando = comando;

                    if(_serialPort.IsOpen)
                        _serialPort.Write(((char)comando).ToString());

                    lblCarattereInviato.Text = ((char)comando).ToString();
                }

                lblContatore.Text = conta.ToString();

                switch (comando)
                {
                    case comandi.CameraSu:
                        lblMovimento.Text = "STOP";
                        lblCamera.Text = "SU";
                        break;

                    case comandi.CameraGiu:
                        lblMovimento.Text = "STOP";
                        lblCamera.Text = "GIU'";
                        break;

                    case comandi.Avanti:
                        lblMovimento.Text = "AVANTI";
                        lblCamera.Text = "-";
                        break;

                    case comandi.Indietro:
                        lblMovimento.Text = "INDIETRO";
                        lblCamera.Text = "-";
                        break;

                    case comandi.Sinistra:
                        lblMovimento.Text = "SINISTRA";
                        lblCamera.Text = "-";
                        break;

                    case comandi.Destra:
                        lblMovimento.Text = "DESTRA";
                        lblCamera.Text = "-";
                        break;


                    case comandi.AvantiLento:
                        lblMovimento.Text = "AVANTI LENTO";
                        lblCamera.Text = "-";
                        break;

                    case comandi.IndietroLento:
                        lblMovimento.Text = "INDIETRO LENTO";
                        lblCamera.Text = "-";
                        break;

                    case comandi.SinistraLento:
                        lblMovimento.Text = "SINISTRA LENTO";
                        lblCamera.Text = "-";
                        break;

                    case comandi.DestraLento:
                        lblMovimento.Text = "DESTRA LENTO";
                        lblCamera.Text = "-";
                        break;

                    default:
                        lblMovimento.Text = "STOP";
                        lblCamera.Text = "-";
                        break;
                }
            }
        }

        void Form1_KeyUp(object sender, KeyEventArgs e)
        {
            inviaComando(comandi.Stop);
        }

        private void cmdConnetti_Click(object sender, EventArgs e)
        {
            webBrowser1.Navigate(txtUrl.Text);

            if (!connesso)
            {
                if (_serialPort == null)
                {
                    _serialPort = new SerialPort("COM" + txtCom.Text , 9600, Parity.None, 8, StopBits.One);
                    _serialPort.Handshake = Handshake.None;
                }

                _serialPort.Open();
                while (!(_serialPort.IsOpen))
                {
                    Application.DoEvents();
                    lblStato.BackColor = Color.Yellow;
                }

                cmdConnetti.Text = "Scollega";
                connesso = true;
                lblStato.BackColor = Color.Green;
            }
            else
            {
                _serialPort.Close();
                cmdConnetti.Text = "Collega";
                connesso = false; ;
                lblStato.BackColor = Color.Red;
            }

        }

        private void tmrControlla_Tick(object sender, EventArgs e)
        {
            if (_serialPort != null)
            {
                if (!_serialPort.IsOpen)
                {
                    if (connesso)
                        _serialPort.Open();
                }

                if (_serialPort.IsOpen)
                    lblStato.BackColor = Color.Green;
                else
                    lblStato.BackColor = Color.Red;
            }

            if (connesso)
                lblStato.BackColor = Color.Green;
        }

        private void webBrowser1_DocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
        {

        }


    }
}
